@@ -41,6 +41,7 @@ sub wxwidgets_configure_extra_flags {
     my $extra_flags = $self->notes( 'extraflags' );
     
     if($extra_flags) {
+	# user has given overrides
     	if( $self->notes( 'graphicscontext' ) ) {
 			$extra_flags .= ' --enable-graphics_ctx';
     	}
@@ -55,19 +56,24 @@ sub wxwidgets_configure_extra_flags {
     # we are determining extra flags
     $extra_flags = '';
     
-    # on Snow Leopard, force wxWidgets 2.8.x builds to be 32-bit;
+    # on Snow Leopard, and above force wxWidgets 2.8.x builds to be 32-bit;
+    # force 2.9 builds to be 32 bit too if we have a 32 bit Perl
     
-    if(    $self->notes( 'build_data' )->{data}{version} =~ /^2.8/
-        && $darwinver >= 10
-        && `sysctl hw.cpu64bit_capable` =~ /^hw.cpu64bit_capable: 1/ ) {
+    if(     $darwinver >= 10
+        &&  `sysctl hw.cpu64bit_capable` =~ /^hw.cpu64bit_capable: 1/
+        && (    $self->notes( 'build_data' )->{data}{version} =~ /^2.8/
+             || $Config{ptrsize} == 4 ) ) {
+             
         print "Forcing wxWidgets build to 32 bit\n";
-        $extra_flags .= ' ' . join ' ', map { qq{$_="-arch i386"} }
-                                     qw(CFLAGS CXXFLAGS LDFLAGS
+		        $extra_flags .= ' ' . join ' ', map { qq{$_="-arch i386"} }
+		                                     qw(CFLAGS CXXFLAGS LDFLAGS
                                         OBJCFLAGS OBJCXXFLAGS);
     }
     
-    # on Snow Leopard and Lion force use of 10.6 SDK for all current builds    
+    
+    # on Snow Leopard and Lion force use of 10.6 SDK for all current builds
     if( $darwinver >= 10 ) {
+        
         my $sdk1 = qq(/Developer/SDKs/MacOSX10.6.sdk);
 		my $sdk2 = qq(/Applications/Xcode.app/Contents/Developer/Platforms/MacOSX.platform/Developer/SDKs/MacOSX10.6.sdk);
     	my $macossdk = ( -d $sdk2 ) ? $sdk2 : $sdk1;
@@ -80,12 +86,13 @@ sub wxwidgets_configure_extra_flags {
 }
 
 sub awx_build_toolkit {
-    # use Cocoa for OS X wxWidgets builds with 64 bit Perl
-    if(    $Config{osname} =~ /darwin/
-        && $Config{ptrsize} == 8 ) {
-        return 'osx_cocoa';
+    my $self = shift;
+    # use Cocoa for OS X wxWidgets >= 2.9
+    # we don't support lower than 2.8 anymore
+    if( $self->notes( 'build_data' )->{data}{version} =~ /^2.8/ ) {
+    	return 'mac';
     } else {
-        return 'mac';
+        return 'osx_cocoa';
     }
 }
 
